@@ -66,7 +66,8 @@ progress_multi <- function(i, labels, count, progress) {
 ##' @importFrom httr GET write_disk status_code config
 fetch_cran_rds_file <- function(file = c("details", "results", "flavors", "issues"),
                                 dest = tempdir(), protocol = c("https", "http"),
-                                overwrite = FALSE, file_prefix = NULL, ...) {
+                                overwrite = FALSE, file_prefix = NULL,
+                                progress = TRUE, ...) {
   file <- match.arg(file)
   protocol <- match.arg(protocol)
   is_ftp <- if (identical(protocol, "ftp")) "/pub/R/" else character(0)
@@ -74,16 +75,20 @@ fetch_cran_rds_file <- function(file = c("details", "results", "flavors", "issue
   dest_file <- file.path(dest, paste0(file_prefix, file))
   if (!(file.exists(dest_file) &&
     file.info(dest_file, extra_cols = FALSE)$size > 0) ||
-      overwrite) {
+    overwrite) {
     file_cran_url <- paste0(cran_url(protocol), is_ftp, "/web/checks/", file)
-    pb <- progress_multi(
-      i = 1, labels = list(paste("Downloading", file)), count = FALSE,
-      progress = requireNamespace("progress", quietly = TRUE)
-    )
+    if (interactive()) {
+      pb <- progress_multi(
+        i = 1, labels = list(paste("Downloading", file)), count = FALSE,
+        progress = requireNamespace("progress", quietly = TRUE) && progress
+      )
+    } else {
+      pb <- NULL
+    }
     d_status <- httr::GET(
       url = file_cran_url,
       httr::write_disk(dest_file, overwrite = overwrite),
-      httr::config(progressfunction = if (interactive()) pb$callback), ...
+      httr::config(progressfunction = pb$callback), ...
     )
 
     if (!identical(httr::status_code(d_status), 200L)) {
@@ -134,8 +139,9 @@ get_cran_rds_file <- function(file, ...) {
 read_crandb_from_email <- function(email, file = "results", ...) {
   crandb <- get_cran_rds_file(file = file, ...)
   maintainer <- tolower(crandb$maintainer)
-  idx <- lapply(tolower(email), function(x)
-    grepl(paste0("<", x, ">"), maintainer, fixed = TRUE))
+  idx <- lapply(tolower(email), function(x) {
+    grepl(paste0("<", x, ">"), maintainer, fixed = TRUE)
+  })
   idx <- Reduce("+", idx)
 
   res <- crandb[as.logical(idx), ]
